@@ -2,9 +2,12 @@ import json
 import requests
 import urllib.parse
 import base64
-from .webtools import (
-    PageResponseObject,
+
+from .statuses import (
     HTTP_STATUS_TOO_MANY_REQUESTS,
+)
+from .response import (
+    PageResponseObject,
     json_to_response,
 )
 
@@ -74,6 +77,16 @@ class RemoteServer(object):
 
         return self.perform_remote_call(link, url, settings)
 
+    def get_linkj(self, url, settings=None):
+        """
+        @returns None in case of error
+        """
+
+        link = self.remote_server
+        link = f"{link}/linkj"
+
+        return self.perform_remote_call(link, url, settings)
+
     def get_pingj(self, url, settings=None):
         """
         @returns None in case of error
